@@ -18,6 +18,10 @@ def get(worker_id):
         "input": {job_input}
     }
     '''
+    if os.environ.get('WEBHOOK_GET_WORK', None) is None:
+        log('WEBHOOK_GET_WORK not set, switching to get_local', 'WARNING')
+        return get_local()
+
     get_work_url = str(os.environ.get('WEBHOOK_GET_WORK')
                        ).replace('$ID', worker_id)
 
@@ -56,7 +60,7 @@ def run(job_id, job_input):
 
     log(f"Started working on {job_id} at {time_job_started} UTC")
 
-    models = inference.Models()
+    models = inference.Model()
     job_output = models.run(job_input)
 
     object_urls = upload.upload_image(job_id, job_output)
@@ -71,7 +75,7 @@ def post(worker_id, job_id, job_output, job_time):
     '''
     Complete the job.
     '''
-    if os.environ.get('TEST_LOCAL', 'false') == 'true':
+    if os.environ.get('WEBHOOK_POST_OUTPUT', None) is None:
         return
 
     job_data = {
