@@ -24,19 +24,15 @@ def start_worker():
         log("Worker zero, not starting TTL timer thread.")
 
     while True:
-        if os.environ.get('TEST_LOCAL', 'false') != 'true':
-            next_job = job.get(worker_life.worker_id)
-        else:
-            next_job = job.get_local()
+        next_job = job.get(worker_life.worker_id)
 
         if next_job is not None:
             worker_life.work_in_progress = True  # Rests when "reset_worker_ttl" is called
+            worker_life.job_id = next_job['id']
 
             try:
-                output_urls, job_duration_ms = job.run(
-                    next_job['id'], next_job['input'])
-                job.post(worker_life.worker_id,
-                         next_job['id'], output_urls, job_duration_ms)
+                output_urls, job_duration_ms = job.run(next_job['id'], next_job['input'])
+                job.post(worker_life.worker_id, next_job['id'], output_urls, job_duration_ms)
             except ValueError as err:
                 job.error(worker_life.worker_id, next_job['id'], str(err))
 
@@ -49,6 +45,6 @@ def start_worker():
 
             worker_life.reset_worker_ttl()
 
-        if os.environ.get('TEST_LOCAL', 'false') == 'true':
+        if os.environ.get('WEBHOOK_GET_WORK', None) is None:
             log("Local testing complete, exiting.")
             break
